@@ -34,9 +34,7 @@
 void mympd_state_save(struct t_mympd_state *mympd_state, bool free_data) {
     // write album cache to disc
     // only for simple mode to save the cached uris
-    if (mympd_state->config->save_caches == true &&
-        mympd_state->config->albums.mode == ALBUM_MODE_SIMPLE)
-    {
+    if (mympd_state->config->albums.mode == ALBUM_MODE_SIMPLE) {
         album_cache_write(&mympd_state->album_cache, mympd_state->config->workdir,
             &mympd_state->mpd_state->tags_album, &mympd_state->config->albums, true);
     }
@@ -44,6 +42,7 @@ void mympd_state_save(struct t_mympd_state *mympd_state, bool free_data) {
     while (partition_state != NULL) {
         last_played_file_save(partition_state);
         preset_list_save(partition_state);
+        jukebox_file_save(partition_state);
         partition_state = partition_state->next;
     }
     mympd_api_home_file_save(&mympd_state->home_list, mympd_state->config->workdir);
@@ -67,10 +66,10 @@ void mympd_state_default(struct t_mympd_state *mympd_state, struct t_config *con
     mympd_state->music_directory = sdsnew(MYMPD_MUSIC_DIRECTORY);
     //configured mpd playlist directory
     mympd_state->playlist_directory = sdsnew(MYMPD_PLAYLIST_DIRECTORY);
-    //comma separated list of albumart names - normal size
-    mympd_state->coverimage_names = sdsnew(MYMPD_COVERIMAGE_NAMES);
-    //comma separated list of albumart names - thumbnails
-    mympd_state->thumbnail_names = sdsnew(MYMPD_THUMBNAIL_NAMES);
+    //comma separated list of image names
+    mympd_state->image_names_sm = sdsnew(MYMPD_IMAGE_NAMES_SM);
+    mympd_state->image_names_md = sdsnew(MYMPD_IMAGE_NAMES_MD);
+    mympd_state->image_names_lg = sdsnew(MYMPD_IMAGE_NAMES_LG);
     mympd_state->tag_list_search = sdsnew(MYMPD_TAG_LIST_SEARCH);
     mympd_state->tag_list_browse = sdsnew(MYMPD_TAG_LIST_BROWSE);
     mympd_state->smartpls_generate_tag_list = sdsnew(MYMPD_SMARTPLS_GENERATE_TAG_LIST);
@@ -184,8 +183,9 @@ void mympd_state_free(struct t_mympd_state *mympd_state) {
     FREE_SDS(mympd_state->view_queue_jukebox_album);
     FREE_SDS(mympd_state->view_browse_radio_webradiodb);
     FREE_SDS(mympd_state->view_browse_radio_favorites);
-    FREE_SDS(mympd_state->coverimage_names);
-    FREE_SDS(mympd_state->thumbnail_names);
+    FREE_SDS(mympd_state->image_names_sm);
+    FREE_SDS(mympd_state->image_names_md);
+    FREE_SDS(mympd_state->image_names_lg);
     FREE_SDS(mympd_state->music_directory);
     FREE_SDS(mympd_state->smartpls_sort);
     FREE_SDS(mympd_state->smartpls_prefix);
@@ -427,6 +427,7 @@ void jukebox_state_default(struct t_jukebox_state *jukebox_state) {
     jukebox_state->max_song_duration = MYMPD_JUKEBOX_MAX_SONG_DURATION;
     jukebox_state->filling = false;
     jukebox_state->last_error = sdsempty();
+    jukebox_state->autostart = true;
 }
 
 /**
