@@ -15,6 +15,8 @@
 
 void jukebox_clear_all(struct t_mympd_state *mympd_state);
 void jukebox_disable(struct t_partition_state *partition_state);
+bool jukebox_trigger_script(struct t_mympd_state *mympd_state, struct t_partition_state *partition_state,
+        bool add_to_queue);
 bool jukebox_run(struct t_mympd_state *mympd_state, struct t_partition_state *partition_state,
     struct t_cache *album_cache);
 
